Introduction
============

All functionality was moved to Products.CMFPlone!

This package provides backward compatible imports and zcml only.

Do not use, except you need to support non migrated addons..